import 'package:cpt_community/modules/my_following/my_following_vm.dart';
import 'package:cs_resources/generated/assets.dart';
import 'package:flutter/cupertino.dart';
import 'package:plugin_platform/engine/toast/toast_engine.dart';
import 'package:riverpod_annotation/riverpod_annotation.dart';
import 'package:shared/utils/log_utils.dart';
import 'package:widgets/load_state_layout.dart';
import 'package:widgets/widget_export.dart';

import 'my_follower_state.dart';

part 'my_follower_vm.g.dart';

@riverpod
class MyFollowerVm extends _$MyFollowerVm {

  bool _needShowPlaceholder = false; //是否展示LoadingView

  // Refresh 控制器
  final EasyRefreshController refreshController = EasyRefreshController(
    controlFinishRefresh: true,  //允许刷新
    controlFinishLoad: true,   //允许加载
  );

  MyFollowerState initState() {
    return MyFollowerState(
        list: []
    );
  }

  @override
  MyFollowerState build(){
    final state = initState();
    Log.d("--------------------------build---------------------");

    return state;
  }

  //刷新页面状态
  void changeLoadingState(LoadState loadState, String? errorMsg) {
    state = state.copyWith(
        loadingState: loadState,
        errorMessage: errorMsg
    );
  }

  // 初始化页面数据
  initPageData() {
    Log.d("----for_sale_vm-----initPageData   ${state.loadingState}");
    WidgetsBinding.instance.addPostFrameCallback((_){
      final myFollowingPageVm = ref.read(myFollowingVmProvider.notifier);
      myFollowingPageVm.tabsRouterChange();
    });
    onRefresh();
  }

  // 上拉加载 更多
  Future loadMore() async {
    Log.d("----for_sale_vm-----loadMore");
    // await Future.delayed(const Duration(seconds: 2));
    // if(state.list.length >= state.count){
    //   return;
    // }else {
    //   int page = state.page + 1;
    //   state = state.copyWith(page: page,);
    //   getListData();
    // }
    // 检查 page 是否为 null，并初始化为 1
    int newCurPage = state.page ?? 1;
    state = state.copyWith(page: ++newCurPage);
    getListData();
  }


  // 下拉刷新
  Future onRefresh() async {
    Log.d("----forsale_vm-----onRefresh ");

    // await Future.delayed(const Duration(seconds: 2));
    state = state.copyWith(page: 1);
    getListData();
  }

  // 重试请求
  Future retryRequest() async {
    state = state.copyWith(page: 1);
    _needShowPlaceholder = true;
    getListData();
  }


  // 获取list 列表数据
  Future getListData<T>() async {
    if (_needShowPlaceholder) {
      changeLoadingState(LoadState.State_Loading, null);
    }

    Log.d("for_sale加载listData数据---------------start--${state.page}---");
    //   try {
    //     //请求网络
    //     Map<String, dynamic>  params = {
    //       "page": state.page,
    //       "limit": state.limit,
    //     };
    //     Log.d("请求参数------$params");
    //     final result = await propertyNewsRepository.fetchPropertyNewsList(params);
    //     Log.d("请求完成结果------${result.data}");
    //     //校验成功失败
    //     if (result.isSuccess) {
    //       // state = state.copyWith(serverTime: result.data);
    //       state = state;
    //   handleList(listResult.data?.rows);
    //       ToastEngine.show("获取数据成功");
    //     } else {
    //   errorMessage = listResult.errorMsg;
    //   changeLoadingState(LoadState.State_Error);
    //       ToastEngine.show(result.errorMsg ?? "Network Load Error");
    //     }
    //   } catch (e) {
    //     ToastEngine.show("Error: $e");
    //   }

    await Future.delayed(const Duration(milliseconds: 1500));
    final List<Map<String, dynamic>> listData = [
      {
        'id':1,
        'avator': 'https://iknow-pic.cdn.bcebos.com/4afbfbedab64034f6c21389bbdc379310b551dba',
        'title': 'Steve Jobs',
        'isFollow': false,
      },
      {
        'id':2,
        'avator': 'https://img2.baidu.com/it/u=3489233687,2364672159&fm=253&fmt=auto&app=120&f=JPEG?w=507&h=500',
        'title': 'William Jefferson',
        'isFollow': true,
      },
    ];

    if (state.page == 1) {
      //刷新的方式
      state = state.copyWith(list: listData);
      refreshController.finishRefresh();
      // //更新展示的状态
      changeLoadingState(LoadState.State_Success, null);
    } else {
      //加载更多
      final allList = state.list;
      allList.addAll(listData);
      state = state.copyWith(list: allList);
      refreshController.finishLoad();

    }

    // 最后赋值
    _needShowPlaceholder = false;

    WidgetsBinding.instance.addPostFrameCallback((_) {
      // 需要更新 my_posts_tabs 里面的数字
      ref.read(myFollowingVmProvider.notifier)
          .updateMyFollowingTabsNum( 'followerCount', state.list!.length, 1);
    });

  }

  handlerSearchChange(String value){}

  handlerSubmitSearch(String value){}

}