import 'package:domain/constants/api_constants.dart';
import 'package:domain/entity/newsfeed_foryou_entity.dart';
import 'package:domain/entity/newsfeed_news_entity.dart';
import 'package:domain/entity/server_time.dart';
import 'package:plugin_platform/platform_export.dart';
import 'package:plugin_platform/http/dio_engine.dart';
import 'package:plugin_platform/http/http_result.dart';
import 'package:riverpod_annotation/riverpod_annotation.dart';
import 'package:shared/utils/log_utils.dart';
import 'package:shared/utils/util.dart';

import 'package:flutter_riverpod/flutter_riverpod.dart';
import 'package:plugin_basic/provider/http_provider/http_provider.dart';


part 'garage_forrent.g.dart';

@Riverpod(keepAlive: true)
GarageForRentRepository garageForRentRepository(Ref ref) {
  final dioEngine = ref.watch(dioEngineProvider);
  return GarageForRentRepository(dioEngine: dioEngine);
}

/*
 * 数据仓库
 */
class GarageForRentRepository {
  DioEngine dioEngine;

  GarageForRentRepository({required this.dioEngine});

  // news feed - news 列表
  Future<HttpResult<Object>> fetchForyouList(
      Map<String, dynamic>? data, {
        CancelToken? cancelToken,
      }) async {
    Map<String, dynamic> params = {};
    params = data!;
    Map<String, String> headers = {};
    headers["Content-Type"] = "application/x-www-form-urlencoded";
    headers["Accept"] = "application/x.yyjobs-api.v1+json";

    final result = await dioEngine.requestNetResult(
      // ApiConstants.apiServerTime, // api 地址
      '/api/v1/user/news-feed/feed/for-you', // api 地址
      params: params,
      headers: headers,
      method: HttpMethod.GET,
      isShowLoadingDialog: false,  //是否展示默认的Loading弹窗
      networkDebounce: true,   //是否防抖防止重复请求
      cancelToken: cancelToken,
    );

    //根据返回的结果，封装原始数据为Bean/Entity对象
    if (result.isSuccess) {
      //重新赋值data或list
      final json = result.getDataJson();
      var data = NewsfeedForyouEntity.fromJson(json!);
      //重新赋值data或list
      return result.convert(data: data);
    }
    return result.convert();
  }

  // news feed -news 点赞/取消点赞
  Future<HttpResult<Object>> fetchLikeClick(
      Map<String, dynamic>? data, {
        CancelToken? cancelToken,
      }) async {
    Map<String, dynamic> params = {};
    params = data!;
    Map<String, String> headers = {};
    headers["Content-Type"] = "application/x-www-form-urlencoded";
    headers["Accept"] = "application/x.yyjobs-api.v1+json";

    final result = await dioEngine.requestNetResult(
      // ApiConstants.apiServerTime, // api 地址
      '/api/v1/user/news-feed/like/click', // api 地址
      params: params,
      headers: headers,
      method: HttpMethod.POST,
      isShowLoadingDialog: true,  //是否展示默认的Loading弹窗
      networkDebounce: true,   //是否防抖防止重复请求
      cancelToken: cancelToken,
    );
    //根据返回的结果，封装原始数据为Bean/Entity对象
    if (result.isSuccess) {
      //重新赋值data或list
      final boolData = result.getDataDynamic();
      // var data = NewsfeedForyouEntity.fromJson(json!);
      //重新赋值data或list
      return result.convert(data: boolData);
    }
    return result.convert();
  }



}
