import 'dart:ui';

import 'package:cs_resources/generated/l10n.dart';
import 'package:flutter/cupertino.dart';
import 'package:riverpod_annotation/riverpod_annotation.dart';
import 'package:shared/utils/log_utils.dart';
import 'package:widgets/picker/date_picker_util.dart';
import '../../form/form_page.dart';
import '../../form/form_types.dart';
import 'apply_state.dart';
import 'package:widgets/picker/option_pick_util.dart';

part 'apply_view_model.g.dart';

@riverpod
class ApplyViewModel extends _$ApplyViewModel {
  @override
  ApplyState build() {
    return ApplyState();
  }

  //设置具体的表单类型
  void setFormType(String formType) {
    final detail = FormTypes.detailPageMap[formType];
    Log.d("applyViewModelProvider - detail:$detail");
    state = state.copyWith(formType: formType, applyDetail: detail);
  }

  //进入下一步页面
  void gotoNextPage() {
    Log.d("applyViewModelProvider - detailPageIndex:${state.detailPageIndex}");
    bool success = FormTypes.startDetailPageByType(state.applyDetail?['detail_pages'], state.detailPageIndex);
    Log.d("applyViewModelProvider - gotoNextPage - success:$success");
    if (!success) {
      FormPage.startInstance();
    } else {
      state.detailPageIndex++;
    }
  }

  //返回的时候处理当前的索引
  void handlePopAction() {
    state.detailPageIndex--;
  }

  //选择一个选项
  void pickOption() {
    OptionPickerUtil.showCupertinoOptionPicker(
      items: ["选项1", "选项2", "选项3"],
      initialSelectIndex: 0,
      onPickerChanged: (_, index) {},
    );
  }

  //选择一个日期,并回调出去
  void pickDate(DateTime? selectedDate, void Function(DateTime) dateCallback) {
    DatePickerUtil.showCupertinoDatePicker(
      selectedDateTime: selectedDate ?? DateTime.now(),
      mode: CupertinoDatePickerMode.date,
      onDateTimeChanged: (date) {
        dateCallback.call(date);
      },
      title: S.current.choose_date,
    );
  }

}
