import 'package:domain/entity/property_sale_rent_entity.dart';
import 'package:plugin_platform/http/http_result.dart';
import 'package:riverpod_annotation/riverpod_annotation.dart';
import 'package:shared/utils/log_utils.dart';
import 'package:plugin_platform/engine/toast/toast_engine.dart';
import 'package:widgets/load_state_layout.dart';
import 'package:widgets/widget_export.dart';
import '../page/property_sale_state.dart';
import '../repository/property_sale_repository.dart';
part 'property_sale_vm.g.dart';

@riverpod
class PropertySaleVm extends _$PropertySaleVm {
  late PropertySaleRepository propertySaleRepository;
  bool _needShowPlaceholder = false; //是否展示LoadingView
  int _page = 1;  // 当前页
  int _limit = 10; // 每页数量
  int _count = 0; // 总条数
  // Refresh 控制器
  final EasyRefreshController refreshController = EasyRefreshController(
    controlFinishRefresh: true,  //允许刷新
    controlFinishLoad: true,   //允许加载
  );

  PropertySaleState initState() {
    return PropertySaleState(
      list: [],
    );
  }

  @override
  PropertySaleState build() {
    // 引入数据仓库
    propertySaleRepository = ref.read(propertySaleRepositoryProvider);
    // 初始化状态
    PropertySaleState state = initState();
    // 初始化列表数据
    return state;
  }

  //刷新页面状态
  void changeLoadingState(LoadState loadState, String? errorMsg) {
    state = state.copyWith(
        loadingState: loadState,
        errorMessage: errorMsg
    );
  }

  // 初始化页面数据
  initPageData() {
    Log.d("----property_news_vm-----initPageData");
    onRefresh();
  }

  // 上拉加载 更多
  Future loadMore() async {
    Log.d("----property_news_vm-----loadMore");
    // await Future.delayed(const Duration(seconds: 2));
    // if(state.list.length >= _count){
    //   return;
    // }else {
    //   int page = _page + 1;
    //   state = state.copyWith(page: page,);
    //   getListData();
    // }
    // 检查 page 是否为 null，并初始化为 1
    _page++;
    getListData();
  }


  // 下拉刷新
  Future onRefresh() async {
    Log.d("----property_news_vm-----onRefresh ");

    // await Future.delayed(const Duration(seconds: 2));
    _page = 1;
    getListData();
  }

  // 重试请求
  Future retryRequest() async {
    _page = 1;
    _needShowPlaceholder = true;
    getListData();
  }


  // 获取list 列表数据
  Future getListData<T>() async {
    if (_needShowPlaceholder) {
      changeLoadingState(LoadState.State_Loading, null);
    }

    Log.d("加载listData数据---------------start--${_page}---");
    //   try {
    //     //请求网络
    //     Map<String, dynamic>  params = {
    //       "page": _page,
    //       "limit": _limit,
    //     };
    //     Log.d("请求参数------$params");
    //     final result = await propertyNewsRepository.fetchPropertyNewsList(params);
    //     Log.d("请求完成结果------${result.data}");
    //     //校验成功失败
    //     if (result.isSuccess) {
    //       // state = state.copyWith(serverTime: result.data);
    //       state = state;
    //   handleList(listResult.data?.rows);
    //       ToastEngine.show("获取数据成功");
    //     } else {
    //   errorMessage = listResult.errorMsg;
    //   changeLoadingState(LoadState.State_Error);
    //       ToastEngine.show(result.errorMsg ?? "Network Load Error");
    //     }
    //   } catch (e) {
    //     ToastEngine.show("Error: $e");
    //   }

    // await Future.delayed(const Duration(milliseconds: 1500));
    // final List<Map<String, dynamic>> listData = [
    //   {
    //     "id": 1,
    //     "title": "18 Sep 2024 BIK 39#09-XX 1337 psd 1001 sqft",
    //     "price": "\$1.338 M",
    //   },
    //   {
    //     "id": 2,
    //     "title": "18 Sep 2024 BIK 39#09-XX 1337 psd 1001 sqft",
    //     "price": "\$1.338 M",
    //   },
    // ];
    //
    // if (_page == 1) {
    //   //刷新的方式
    //   state = state.copyWith(list: listData);
    //   refreshController.finishRefresh();
    //   //更新展示的状态
    //   changeLoadingState(LoadState.State_Success, null);
    // } else {
    //   //加载更多
    //   final allList = state.list;
    //   if(allList.length >= _count! * _limit!){
    //     //更新展示的状态
    //     changeLoadingState(LoadState.State_Success, null);
    //     refreshController.finishLoad(IndicatorResult.noMore, true);
    //   }else {
    //     allList.addAll(listData);
    //     state = state.copyWith(list: allList);
    //     refreshController.finishLoad();
    //   }
    // }
    //
    // // 最后赋值
    // _needShowPlaceholder = false;


    try {
      //请求网络
      Map<String, dynamic>  params = {
        "type": 1, // 1 sale 2 rent
        "page": _page,
        "limit": _limit,
      };
      Log.d("请求参数------$params");
      final result = await propertySaleRepository.fetchList(params);
      //校验成功失败
      if (result.isSuccess) {
        // state = state.copyWith(count: (result.data as PropertySaleRentEntity).count);
        handlerResultList((result.data  as PropertySaleRentEntity).list);
      } else {
        String errorMessage = result.errorMsg!;
        changeLoadingState(LoadState.State_Error, errorMessage);
        ToastEngine.show(result.errorMsg ?? "Network Load Error");
      }
    } catch (e) {
      ToastEngine.show("Error: $e");
    }

  }


  void handlerResultList(List<PropertySaleRentList>? list) {
    if (list != null && list.isNotEmpty) {
      //有数据，判断是刷新还是加载更多的数据
      if (_page == 1) {
        //刷新的方式
        state.list!.clear();
        state.list!.addAll(list.map((item)=> item.toJson()).toList());
        refreshController.finishRefresh();
        //更新展示的状态
        changeLoadingState(LoadState.State_Success, null);
      } else {
        //加载更多
        final allList = state.list;
        state = state.copyWith(list: allList);
        refreshController.finishLoad();
      }
    } else {
      if (_page == 1) {
        //展示无数据的布局
        state.list!.clear();
        changeLoadingState(LoadState.State_Empty, null);
        refreshController.finishRefresh();
      } else {
        //展示加载完成，没有更多数据了
        if(state.list!.length == 0){
          changeLoadingState(LoadState.State_Empty, null);
          refreshController.finishLoad();
        }else {
          if(_needShowPlaceholder){
            changeLoadingState(LoadState.State_Success, null);
          }
        }
        //更新展示的状态
        refreshController.finishLoad(IndicatorResult.noMore);
      }
    }
  }

}
